@@ -13,4 +13,10 @@ def file_remove(path):
 
 
 def create_folder(path):
-    os.mkdir(path)
\ No newline at end of file
+    os.mkdir(path)
+    
+def path_get_file_name(path):
+    return path.split('\\')[-1]
+
+def file_name_get_suffix_name(fill_name):
+    return fill_name.split('.')[-1]
\ No newline at end of file
