@@ -2,7 +2,7 @@
 import time
 
 def get_time():
-    return time.strftime('[%Y-%m-%d %H:%M:%S]')
+    return time.strftime('%Y-%m-%d %H:%M:%S')
 
 
 def time_sleep(stime):
